clear

k1=3; k2=3; k3=3;

k= [ k1+k2 -k2 0;
    -k2 k2+k3 -k3;
    0 -k3 k3];

m1=1; m2=1; m3=1;

m=[m1 m2 m3];
m=diag(m);

c=.01*k;

%state matrix

a=[0*eye(3) eye(3);
    -inv(m)*k -inv(m)*c];

%input matrix (single force at mass 3)
b0=[0 0 1]';
b=[0*b0;
    inv(m)*b0];

%output matrix (single; displacement at mass 1)
c1=[1 0 0 0 0 0];
%output matrix (single; displacement at mass 2)
c2=[0 1 0 0 0 0];
%output matrix (single; displacement at mass 3)
c3=[0 0 1 0 0 0];

%output matrix (single; velocity at mass 1)
c=[0 0 0 1 0 0];
%c=c1;

%feedthrough matrix (direct input to output)
d=[0];

%modal coordinates
[va, am, bm, cm]=modal1b(a,b,c);

% unit impulse response
dt=0.1;
t=0:dt:1000-dt;
sys = ss(a,b,c,d);
y=impulse(sys,t);

figure(1)
subplot(211);
plot(t,y)
axis([0 300 -0.8 0.8]);
xlabel('time (s)');
ylabel('velocity of mass 1')

%spectrum of impulse response (freq. content)
nn=max(size(t));
n=nn/4;
p=spectrum(y,n);
pp=sqrt(p(:,1));
fs=1/dt;
f=fs*(0:n/2-1)/n;
om=2*pi*f;
nf=max(size(f));
subplot(212);
plot(om,pp(1:nf,1));
axis([0 5 0 1.8]);
xlabel('frequency (rad/s)')
ylabel('spectrum of velocity of mass 1')

% transfer function magnitude and phase plots
figure(2)
subplot(211)
w=logspace(-1,1,900);
[ma ph]=bode(a,b,c,d,1,w);
loglog(w,ma);
axis([0.1 10 0.01 100])
xlabel('frequency (rad/s)')
ylabel('magnitude')

subplot(212)
semilogx(w,ph)
xlabel('frequency (rad/s)')
ylabel('phase (deg)')

%single mode analysis
%mode 1
nn=1:2;
am1=am(nn,nn);
bm1=bm(nn,:);
cm1=cm(:,nn);
ym1=impulse(am1,bm1,cm1,d,1,t);
[ma1,ph1]=bode(am1,bm1,cm1,d,1,w);

%mode 2
nn=3:4;
am2=am(nn,nn);
bm2=bm(nn,:);
cm2=cm(:,nn);
ym2=impulse(am2,bm2,cm2,d,1,t);
[ma2,ph2]=bode(am2,bm2,cm2,d,1,w);

%mode 3
nn=5:6;
am3=am(nn,nn);
bm3=bm(nn,:);
cm3=cm(:,nn);
ym3=impulse(am3,bm3,cm3,d,1,t);
[ma3,ph3]=bode(am3,bm3,cm3,d,1,w);

% plots - impulse responses
figure(3)
subplot(311)
plot(t,ym1)
axis([0 200 -0.4 0.4])
xlabel('time (s)')
ylabel('mode 1')

subplot(312)
plot(t,ym2)
axis([0 200 -0.4 0.4])
xlabel('time (s)')
ylabel('mode 2')

subplot(313)
plot(t,ym3)
axis([0 200 -0.4 0.4])
xlabel('time (s)')
ylabel('mode 3')

%plots - transfer functions
figure(4)
subplot(211)
loglog(w,ma,w,ma1,':',w,ma2,':',w,ma3,':')
xlabel('frequency (rad/s)')
ylabel('magnitude')

subplot(212)
semilogx(w,ph,w,ph1,':',w,ph2,':',w,ph3,':')
xlabel('frequency (rad/s)')
ylabel('phase (deg)')
